@@ -7,7 +7,7 @@ class Logger:
     def __init__(self, log_filepath=None, max_lines=10_000, level='info', name=None, log_to_file=True):
         filename = Path(sys.argv[0]).stem
         if not log_filepath:
-            log_filepath = f'{os.getcwd()}/{filename}.txt'
+            log_filepath = f'{os.getcwd()}/logs/{filename}.txt'
         else:
             path_tree = log_filepath.split('/') # ['logs', 'bot.txt']
             if len(path_tree) > 1:
@@ -87,8 +87,8 @@ class Logger:
                 # Rename the current log file to FILE_NAME_2nd_log.txt
                 current_datetime = datetime.now()
                 formatted_datetime = current_datetime.strftime('%Y-%m-%d %H-%M-%S')
-                archive_log_filepath = log_filepath.replace('.txt', f' {formatted_datetime}.txt')
-                os.replace(self.log_filepath, self.backup_log_filepath)
+                archive_log_filepath = self.log_filepath.replace('.txt', f' {formatted_datetime}.txt')
+                os.replace(self.log_filepath, archive_log_filepath)
 
                 log_file = logging.FileHandler(self.log_filepath, mode='w', encoding='utf-8')
                 log_format = logging.Formatter(fmt=self.indent + '%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
